@@ -37,12 +37,18 @@ SEXP rastget(SEXP G, SEXP layers, SEXP flayers) {
 
    int ival;
    double val;
+   char *errs;
 
 
    char *name="rastget()";
    R_G_init(name);
    
-   G_get_window(&cellhd);
+    /* G_get_window(&cellhd); calls G_fatal_error internally */
+    if((errs = (G__get_window (&cellhd,"","WIND",G_mapset())))) {
+        G_free (errs);
+        G_fatal_error ("Bad or no region for current mapset");
+    }
+   /* G_get_window(&cellhd); */
 
 
    if (NUMERIC_POINTER(VECTOR_ELT(G, 3))[0] != cellhd.north)
